Output

Enum Output 

pub enum Output {
    Coin {
        to: Address,
        amount: Word,
        asset_id: AssetId,
    },
    Contract(Contract),
    Change {
        to: Address,
        amount: Word,
        asset_id: AssetId,
    },
    Variable {
        to: Address,
        amount: Word,
        asset_id: AssetId,
    },
    ContractCreated {
        contract_id: ContractId,
        state_root: Bytes32,
    },
}

Variants



Coin

Fields

amount: Word
asset_id: AssetId


Contract(Contract)



Change

Fields

amount: Word
asset_id: AssetId


Variable

Fields

amount: Word
asset_id: AssetId


ContractCreated

Fields

contract_id: ContractId
state_root: Bytes32

Implementations

Source

impl Output

pub const fn repr(&self) -> OutputRepr

pub const fn coin(to: Address, amount: Word, asset_id: AssetId) -> Self

pub const fn contract( input_index: u16, balance_root: Bytes32, state_root: Bytes32, ) -> Self

pub const fn change(to: Address, amount: Word, asset_id: AssetId) -> Self

pub const fn variable(to: Address, amount: Word, asset_id: AssetId) -> Self

pub const fn contract_created( contract_id: ContractId, state_root: Bytes32, ) -> Self

pub const fn asset_id(&self) -> Option<&AssetId>

pub const fn to(&self) -> Option<&Address>

pub const fn amount(&self) -> Option<Word>

pub const fn input_index(&self) -> Option<u16>

pub const fn balance_root(&self) -> Option<&Bytes32>

pub const fn state_root(&self) -> Option<&Bytes32>

pub const fn contract_id(&self) -> Option<&ContractId>

pub const fn is_coin(&self) -> bool

pub const fn is_change(&self) -> bool

pub const fn is_variable(&self) -> bool

pub const fn is_contract(&self) -> bool

pub const fn is_contract_created(&self) -> bool

pub fn message_nonce(txid: &Bytes32, idx: Word) -> Nonce

pub fn message_digest(data: &[u8]) -> Bytes32

pub fn prepare_sign(&mut self)

Empties fields that should be zero during the signing.

pub fn prepare_init_execute(&mut self)

Prepare the output for VM initialization for script execution or predicate verification

Source

impl Output

pub fn check(&self, index: usize, inputs: &[Input]) -> Result<(), ValidityError>

Validate the output of the transaction.

This function is stateful - meaning it might validate a transaction during VM initialization, but this transaction will no longer be valid in post-execution because the VM might mutate the message outputs, producing invalid transactions.